mod table_directory;

use std::io::{BufReader, Read, Seek};

use bincode::{Options, Result};
use table_directory::TableDirectory;

fn deserialize<R: Read + Seek, T: serde::de::DeserializeOwned>(reader: R) -> Result<T> {
	bincode::options().with_big_endian().with_fixint_encoding().deserialize_from::<R, T>(reader)
}

#[derive(Debug)]
pub struct Font<R: Read + Seek> {
	data_source: BufReader<R>,
	table_directory: TableDirectory
}
	
impl<R: Read + Seek> Font<R> {
	pub fn new(reader: R) -> Result<Self> {
		let mut buf_reader = BufReader::new(reader);
		let table_directory = TableDirectory::new(&mut buf_reader)?;

		Ok(Font {
			data_source: buf_reader,
			table_directory: table_directory
		})
	}
}

