use std::{collections::HashMap, io::{Read, Seek}};

use bincode::Result;
use serde::Deserialize;

use crate::font::deserialize;

#[derive(Deserialize, Debug)]
struct TableDirectoryHeader {
	sfnt_version: u32,
	num_tables: u16,
}

#[derive(Deserialize, Debug)]
struct TableDirectoryRecord {
	pub table_tag: u32,
	pub checksum: u32,
	pub offset: u32,
	pub length: u32
}

#[derive(Debug, Default)]
pub struct TableDirectory(pub HashMap<u32, TableDirectoryRecord>);

impl TableDirectory {
	pub fn new<R: Read + Seek>(reader: &mut R) -> Result<TableDirectory> {
		let header: TableDirectoryHeader = deserialize(reader.by_ref())?;
		let mut tables: HashMap<u32, TableDirectoryRecord> = HashMap::with_capacity(header.num_tables as usize);

		reader.seek_relative(3 * size_of::<u16>() as i64)?;
		
		for _ in 0..header.num_tables {
			let record: TableDirectoryRecord = deserialize(reader.by_ref())?;
			tables.insert(record.table_tag, record);
		}

		Ok(TableDirectory(tables))
	}
}
